# ApplicationConfig

The generic list of configurations that will be passed to environment.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**authentication_config** | [**ApplicationAuthenticationConfig**](ApplicationAuthenticationConfig.md) |  | [optional] 
**oidc_config** | [**OIDCProxyConfig**](OIDCProxyConfig.md) |  | [optional] 
**security** | [**ApplicationSecurity**](ApplicationSecurity.md) |  | [optional] 
**additional_context** | [**ApplicationAdditionalContext**](ApplicationAdditionalContext.md) |  | [optional] 
**dynamic_config** | [**ApplicationDynamicConfig**](ApplicationDynamicConfig.md) |  | [optional] 
**client_injection** | [**ClientInjection**](ClientInjection.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


